@@ -25,6 +25,30 @@ Medical Language System
 
 =head2 Optional Arguments:
 
+=head3 --config FILE
+
+This is the configuration file. The format of the configuration 
+file is as follows:
+
+SAB :: <include|exclude> <source1, source2, ... sourceN>
+
+REL :: <include|exclude> <relation1, relation2, ... relationN>
+
+For example, if we wanted to use the MSH vocabulary with only 
+the RB/RN relations, the configuration file would be:
+
+SAB :: include MSH
+REL :: include RB, RN
+
+or 
+
+SAB :: include MSH
+REL :: exclude PAR, CHD
+
+If you go to the configuration file directory, there will 
+be example configuration files for the different runs that 
+you have performed.
+
 =head3 --depth
 
 The minimum and maximum depth of the least common subsummer
@@ -448,7 +472,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findLeastCommonSubsumer.pl,v 1.11 2010/03/01 23:06:23 btmcinnes Exp $';
+    print '$Id: findLeastCommonSubsumer.pl,v 1.12 2010/03/31 19:38:01 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
