@@ -2,12 +2,14 @@
 
 =head1 NAME
 
-getCuiList.pl - This program returns a list of CUIs based on the configuration file. 
+getCuiList.pl - This program removes the temporary table 
+and associated files that are created based on the configuration 
+file.
 
 =head1 SYNOPSIS
 
-This program returns a list of CUIs based on the sources and relations specified 
-in the configuration file.
+This program removes the temporary table and associated files that 
+are created based on the configuration file.
 
 =head1 USAGE
 
@@ -24,14 +26,11 @@ SAB :: <include|exclude> <source1, source2, ... sourceN>
 
 REL :: <include|exclude> <relation1, relation2, ... relationN>
 
-RELA :: <include|exclude> <rela1, rela2, .... relaN> (optional)
-
 For example, if we wanted to use the MSH vocabulary with only 
 the RB/RN relations, the configuration file would be:
 
 SAB :: include MSH
 REL :: include RB, RN
-RELA :: include inverse_isa, isa
 
 or 
 
@@ -141,7 +140,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s")) or die ("Please check the above mentioned option(s).\n");
+GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s");
 
 
 #  if help is defined, print out help
@@ -195,6 +194,10 @@ if(defined $opt_socket) {
 
 $umls = UMLS::Interface->new(\%option_hash); 
 die "Unable to create UMLS::Interface object.\n" if(!$umls);
+($errCode, $errString) = $umls->getError();
+die "$errString\n" if($errCode);
+
+&errorCheck($umls);
 
 my $hashref = $umls->getCuiList();
 
@@ -202,6 +205,15 @@ foreach my $cui (sort keys %{$hashref}) {
     print "$cui\n";
 }
 
+sub errorCheck
+{
+    my $obj = shift;
+    ($errCode, $errString) = $obj->getError();
+    print STDERR "$errString\n" if($errCode);
+    exit if($errCode > 1);
+}
+
+
 ##############################################################################
 #  function to output minimal usage notes
 ##############################################################################
@@ -246,7 +258,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getCuiList.pl,v 1.4 2010/11/03 14:41:25 btmcinnes Exp $';
+    print '$Id: getCuiList.pl,v 1.1 2010/01/21 16:42:47 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
